@@ -5,7 +5,7 @@ function(formula,data,family=gaussian) {
 			data <- environment(formula)
 		else  
 			data <- environment()
-		wasdata <- 0
+#		wasdata <- 0
 	} else {
 		if (is(data,"gwaa.data")) {
 			data <- data@phdata
@@ -13,8 +13,8 @@ function(formula,data,family=gaussian) {
 		else if (!is(data,"data.frame")) {
 			stop("data argument should be of gwaa.data or data.frame class")
 		}
-		attach(data,pos=2,warn.conflicts=FALSE)
-		wasdata <- 1
+#		attach(data,pos=2,warn.conflicts=FALSE)
+#		wasdata <- 1
 	}
 	
 	if (is.character(family)) 
@@ -25,15 +25,20 @@ function(formula,data,family=gaussian) {
            print(family)
            stop("'family' not recognized")
 	}
+	
+	if ( is(try(formula,silent=TRUE),"try-error") ) { 
+		formula <- data[[as(match.call()[["formula"]],"character")]] 
+	}
+	
 	if (is(formula,"formula")) {
 		mf <- model.frame(formula,data,na.action=na.omit,drop.unused.levels=TRUE)
 		y <- model.response(mf)
 		desmat <- model.matrix(formula,mf)
 		lmf <- glm.fit(desmat,y,family=family)
-		if (wasdata) 
-			mids <- rownames(data) %in% rownames(mf)
-		else 
-			mids <- (!is.na(get(as.character(formula[2]))))
+#		if (wasdata) 
+#			mids <- rownames(data) %in% rownames(mf)
+#		else 
+		mids <- complete.cases(desmat,y)
 		resid <- lmf$resid
 #		print(formula)
 	} else if (is(formula,"numeric") || is(formula,"integer") || is(formula,"double")) {
@@ -47,7 +52,7 @@ function(formula,data,family=gaussian) {
 		stop("formula argument must be a formula or one of (numeric, integer, double)")
 	}
 	y <- (resid-mean(resid))/sd(resid)
-	if (wasdata==1) detach(data)
+#	if (wasdata==1) detach(data)
 	tmeas <- as.logical(mids)
 	out <- rep(NA,length(mids))
 	out[tmeas] <- y
