@@ -1,15 +1,15 @@
-.onLoad <- function(lib, pkg) {
+.onAttach <- function(lib, pkg) {
 	## this is something which should be fixed: both version 
 	## and date can come from DESCRIPTION!
 	#pkgDescription <- packageDescription(pkg)
 	#pkgVersion <- pkgDescription$Version
 	#pkgDate <- pkgDescription$Date
-	pkgVersion <- "1.7-2"
-	pkgDate <- "September 14, 2012"
+	pkgVersion <- "1.7-3"
+	pkgDate <- "January 09, 2013"
 	welcomeMessage <- paste(pkg," v. ",pkgVersion," (",pkgDate,") loaded\n",sep="")
 	# check if CRAN version is the same as loaded
-	cranVersion <- checkPackageVersionOnCRAN(pkg)
-	if (!is.null(cranVersion)) 
+	cranVersion <- try( checkPackageVersionOnCRAN(pkg) )
+	if (!is.null(cranVersion) & !( class(cranVersion) == "try-error") ) 
 		if (pkgVersion != cranVersion) {
 			welcomeMessage <- paste(welcomeMessage,
 					"\nInstalled ",pkg," version (",pkgVersion,") is not the same as stable\n",
